/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {

dojo.provide("com.ibm.rational.report.web.core.app.internal.SecurityManager");

dojo.require("com.ibm.team.repository.web.client.session.Session");
dojo.require("com.ibm.team.process.web.client.projectarea");
dojo.require("com.ibm.rational.report.web.core.client.internal.SecurityClient");
dojo.require("com.ibm.rational.report.web.core.client.internal.UserClient");
dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");

var session					= com.ibm.team.repository.web.client.session;
var SecurityClient			= com.ibm.rational.report.web.core.client.internal.SecurityClient;
var UserClient				= com.ibm.rational.report.web.core.client.internal.UserClient;
var ServiceResponseHandler 	= com.ibm.team.repository.web.transport.ServiceResponseHandler;

/**
 * Manages the security associated with the report tree folders and nodes.
 */
com.ibm.rational.report.web.core.app.internal.SecurityManager = function(controller) {
	
	this._controller = controller;
	
	this._authenticatedUser = null;
	this._isProjectLead = false;
	this._isAdmin = false;
	this._updateReportFolderPermissionId = "_zp4zMNFSEdyc-qR8T8L4ww";
	this._updateReportDesignPermissionId = "_T8P6cNBaEdyjWKCaizvXyQ";
	this._updateReportQueryPermissionId = "_zqDLQNFSEdyc-qR8T8L4ww";
	this._updateReportSnapshotPermissionId = "_zqJR4NFSEdyc-qR8T8L4ww";
	
	this.init = function() {
		this._authenticatedUser = session.getAuthenticatedContributor();
		
		var srh = new ServiceResponseHandler(this, "_getIsProjectLead", "_getIsProjectLeadError");
		UserClient.getIsProjectLead(srh, {name: this._authenticatedUser.userId});
	};
	
	this._getIsProjectLead = function(isProjectLead) {
		this._isProjectLead = (isProjectLead == "true");
	};
	
	this._getIsProjectLeadError = function() {
		this._isProjectLead = false;
	};
	
	this.isGuest = function() {
		return session.isGuest();
	};

	this.isAdmin = function() {
		if (this.isGuest()) {
			return false;
		}
		return this._isAdmin;
	};
	
	this.isProjectLead = function() {
		if (this.isGuest()) {
			return false;
		}
		return this._isProjectLead;
	};	
	
	this.getUserId = function() {
		var user = this.getUser();
		return (user == null) ? "" : user.name;
	};	
	
	this.getUser = function() {
		if (this.isGuest()) {
			return null;
		}
		return session.getAuthenticatedContributor();
	};
	
	this.isOwner = function(node) {
		if ((typeof node != "undefined") && (node != null)) {
			if (node.owner) {
				var user = this.getUser();	
				if (user.itemId == node.owner.itemId) {
					return true;
				}
			}
		}
		
		return false;
	};	
	
	this.canShare = function(node) {
		if (this._isProjectLead == false) {
			return false;
		}
		
		if ((typeof node != "undefined") && (node != null) && node.shared) {
			if (node.owner) {
				var user = this.getUser();
				if (user.itemId != node.owner.itemId) {
					return false;
				}
			}
		}
		
		return true;
	};
	
	this.canUnshare = function(node) {
		return this.canShare(node);
	};
	
	this.canEdit = function(node, callback) {
		this._editable = false;		
		if ((typeof node != "undefined") && (node != null)) {
			var user = this.getUser();
			if (node.owner) {					
				if (user.itemId == node.owner.itemId) {	
					this._editable = true;
				}
			}
			
			this._callback = callback;
			
			var srh = new ServiceResponseHandler(this, "_getPermissionCheckSuccess", "_getPermissionCheckError");
			var itemId = node.itemId;
			var permissionId = this._updateReportFolderPermissionId;
			if (node.report) {
				itemId = node.report.itemId;
				if (node.nodeType == "REPORT_DESIGN") {
					permissionId = this._updateReportDesignPermissionId;
				}
				if (node.nodeType == "REPORT_QUERY") {
					permissionId = this._updateReportQueryPermissionId;
				}
				if (node.nodeType == "REPORT_SNAPSHOT") {
					permissionId = this._updateReportSnapshotPermissionId;			
				}
			}
			SecurityClient.getPermissionCheck(srh, {repositoryItemId: itemId,
				principalId: this._authenticatedUser.userId, permissionId: permissionId});
		}
	};
	
	this._getPermissionCheckSuccess = function(result) {
		if (typeof this._callback != "undefined") {
			this._callback(this._editable || (result == "true"));
		}
	};
	
	this._getPermissionCheckError = function(error) {
		if (typeof this._callback != "undefined") {
			this._callback(false);
		}
	};
	
};

})();
